
# React shopping cart

[![npm](https://img.shields.io/npm/v/react-shopping-cart.svg)](https://www.npmjs.com/package/react-shopping-cart)
[![Build Status](https://travis-ci.org/olegnn/react-shopping-cart.svg?branch=master)](https://travis-ci.org/olegnn/react-shopping-cart)
[![npm](https://img.shields.io/npm/dm/react-shopping-cart.svg)](https://www.npmjs.com/package/react-shopping-cart)
[![peerDependencies Status](https://david-dm.org/olegnn/react-shopping-cart/peer-status.svg)](https://david-dm.org/olegnn/react-shopping-cart?type=peer)
[![dependencies](https://david-dm.org/olegnn/react-shopping-cart.svg)](https://david-dm.org/olegnn/react-shopping-cart)
[![devDependencies Status](https://david-dm.org/olegnn/react-shopping-cart/dev-status.svg)](https://david-dm.org/olegnn/react-shopping-cart?type=dev)

Shopping cart package provides several components:
- [__Cart__](#cart)
- [__Product__](#product)
- [__CheckoutButton__](#checkoutbutton)

which can be used separately or in union.
By default [__Redux__](https://github.com/reactjs/redux) is the framework to operate with data.

So, it's your choice to use Redux or not, but its reducers, actions and action types are already included.

Pay attention! All components are  [__Pure__](https://facebook.github.io/react/docs/react-api.html#react.purecomponent).

**Meta**

-   **author**: Oleg Nosov &lt;olegnosov1@gmail.com>
-   **license**: MIT

## Demo

Production demo: [`https://www.solarleague.org/shop/macbook-case/`](https://www.solarleague.org/shop/macbook-case/)

[`Latest version demo (example1)`](https://olegnn.github.io/)

**Usage**
```shell
yarn add react-shopping-cart
```
```shell
npm i --save react-shopping-cart
```

**Examples**


In all cases you must include bootstrap version 4 (^alpha 0.6) in your project
```javascript
import 'bootstrap/dist/css/bootstrap.css';
```
And if you want to see animation, also include animate.css
```javascript
import 'animate.css/animate.min.css';
```
Also want some icons?
```javascript
import 'font-awesome/css/font-awesome.min.css';
```

__With Redux.__ After store initialization you must dispatch setCartCurrency action or 'USD' will be used as cart's currency.
```javascript
import React, { PureComponent } from 'react';
import { Provider } from 'react-redux';
import { createStore, combineReducers } from 'redux';
import {
  Cart,
  Product,
  CheckoutButton,
  cartLocalization,
  cartReducer,
  setCartCurrency,
} from 'react-shopping-cart';


import 'bootstrap/dist/css/bootstrap.css';
import 'animate.css/animate.min.css';
import 'font-awesome/css/font-awesome.min.css';

const { getDefaultLocalization } = cartLocalization;

// You may take localization object from wherever you want, that's just an example
// For more information, see localization section
const iPadCaseLocalization = {
  color: 'Color',
  iPadCase: 'iPad case',
  red: 'Red',
  green: 'Green',
  yellow: 'Yellow',
  GBP: '£',
  EUR: '€',
  USD: '$',
};

const iPadPropertiesWithAdditionalCostLocalization = {
  yellow: 'Yellow (+{cost}{localizedCurrency})',
};

const store = createStore(
  combineReducers(
    {
      cart: cartReducer,
      // Your own reducers, sir
    }
  )
);

store.dispatch(
  setCartCurrency('USD'),
);


class App extends PureComponent {

  state = {
    product: {
      name: 'iPadCase',
      id: 'ipad-case',
      path: '/shop/ipad-case/',
      properties: {
        color: ['red', 'green', {
          additionalCost: {
            GBP: 1,
            EUR: 2,
            USD: 3.50,
          },
          value: 'yellow',
        }],
      },
      propertiesToShowInCart: ['color'],
      prices: { GBP: 70, EUR: 80, USD: 90 },
      currency: 'GBP',
      imageSrc: '1-483x321.jpeg',
    },
    getProductLocalization:
      getDefaultLocalization(
        'product',
        'en',
        {
          ...iPadCaseLocalization,
          ...iPadPropertiesWithAdditionalCostLocalization
        }
      ),
    getCheckoutButtonLocalization:
      getDefaultLocalization(
        'checkoutButton',
        'en',
        iPadCaseLocalization,
      ),
    getCartLocalization:
      getDefaultLocalization(
        'cart',
        'en',
        iPadCaseLocalization
      )
  };

  render() {

    const {
      product,
      getCheckoutButtonLocalization,
      getProductLocalization,
      getCartLocalization,
    } = this.state;

    const checkoutButtonElement =
      <CheckoutButton
        getLocalization={
          getCheckoutButtonLocalization
        }
        checkoutURL="/to/my/checkout"
      />;
    return (
      <Provider store={store}>
        <div className="container">
          <Product
            {...product}
            checkoutButton={checkoutButtonElement}
            getLocalization={
              getProductLocalization
            }

          />
          <Cart
            checkoutButton={checkoutButtonElement}
            getLocalization={
              getCartLocalization
            }
          />
        </div>
      </Provider>
    );
  }
}

export default App;
```

```javascript
// You may also import actions and actionTypes

import { cartActions, cartActionTypes } from 'react-shopping-cart';

// And do some cool things with them
```

__Without redux__
```javascript
import React, { PureComponent } from 'react';
import {
  CartComponent,
  ProductComponent,
  CheckoutButtonComponent,
  cartLocalization,
} from 'react-shopping-cart';


import 'bootstrap/dist/css/bootstrap.css';
import 'animate.css/animate.min.css';
import 'font-awesome/css/font-awesome.min.css';

const { getDefaultLocalization } = cartLocalization;

// You may take localization object from wherever you want, that's just an example
// For more information, see localization section
const iPadCaseLocalization = {
  color: 'Color',
  iPadCase: 'iPad case',
  red: 'Red',
  green: 'Green',
  yellow: 'Yellow',
  GBP: '£',
  EUR: '€',
  USD: '$',
};

const iPadPropertiesWithAdditionalCostLocalization = {
  yellow: 'Yellow (+{cost}{localizedCurrency})',
};

class App extends PureComponent {

  state = {
    products: {},
    product: {
      name: 'iPadCase',
      id: 'ipad-case',
      path: '/shop/ipad-case/',
      properties: {
        color: ['red', 'green', {
          additionalCost: {
            GBP: 1,
            EUR: 2,
            USD: 3.50,
          },
          value: 'yellow',
        }],
      },
      propertiesToShowInCart: ['color'],
      prices: { GBP: 70, EUR: 80, USD: 90 },
      currency: 'GBP',
      imageSrc: '1-483x321.jpeg',
    },
    getProductLocalization:
      getDefaultLocalization(
        'product',
        'en',
        {
          ...iPadCaseLocalization,
          ...iPadPropertiesWithAdditionalCostLocalization
        }
      ),
    getCheckoutButtonLocalization:
      getDefaultLocalization(
        'checkoutButton',
        'en',
        iPadCaseLocalization,
      ),
    getCartLocalization:
      getDefaultLocalization(
        'cart',
        'en',
        iPadCaseLocalization
      )
  };

  addProduct = (key, product, currency) =>
    void this.setState(
      (
        {
          products:
            {
              [key]: cartProduct = { quantity: 0 },
              ...restOfProducts
            }
        }
      ) => ({
        products: {
          ...restOfProducts,
          [key]: {
            ...product,
            quantity:
              product.quantity +
              cartProduct.quantity,
          }
        }
      })
    );

  generateProductKey = (id, properties) =>
    `${id}/${Object.entries(properties).join('_')}`;

  updateProduct = (key, updatedProduct) => void console.log(':)');

  removeProduct = key => void console.log(':C');

  render() {

    const {
      addProduct,
      generateProductKey,
      updateProduct,
      removeProduct,
      state,
    } = this;

    const {
      getProductLocalization,
      getCheckoutButtonLocalization,
      getCartLocalization,
      products,
      product,
    } = state;

    const checkoutButtonElement =
      <CheckoutButtonComponent
        grandTotal={500}
        hidden={false}
        checkoutURL="/to/my/checkout"
        currency="GBP"
        getLocalization={getCheckoutButtonLocalization}
      />;
    return (
      <div className="container">
        <ProductComponent
          {...product}
          checkoutButton={checkoutButtonElement}
          onAddProduct={
            addProduct
            // Help product to get into the cart
          }
          generateProductKey={
            generateProductKey
                    // create product key as you wish
          }
          getLocalization={getProductLocalization}
        />


        <CartComponent
          products={
            products
            // Provide your own product's Object(Look at Products)
          }
          onUpdateProduct={
            updateProduct
            // Update something
          }
          getLocalization={
            getCartLocalization
          }
          currency="GBP"
          onRemoveProduct={
            removeProduct
            // Remove something
          }
          checkoutButton={
            checkoutButtonElement
          }
          isCartEmpty={
            false
          }
          getLocalization={getCartLocalization}
        />
      </div>
    );
  }
}

export default App;
```

## Localization

The default localization library is [intl-messageformat](https://github.com/yahoo/intl-messageformat).
In order to localize your cart, you can chose one of the possible ways:
- Create your own __getLocalization__ function and pass it as prop to the cart's components
- Create getLocalization function with bound localization using __defaultLocalization__ object and __getLocalization__,  __getDefaultLocalization__ functions from _cartLocalization_ module, pass it as prop to the cart's components
- Don't do anything and see only default language in your cart :C

Generally, components require a function, which takes id and params(optional) and returns string, based on received arguments.

The first one should look like that if you're also using intl-messageformat:

```javascript
  import React from 'react';
  import IntlMessageFormat from 'intl-messageformat';
  import { Cart } from 'react-shopping-cart';

  const localization = {
    en: {
      cart : {
        GBP: '£',
      },
    },
  };

  const getLocalization = (localizationPart, language, id, params = {}) =>  
    new IntlMessageFormat(localizationPart[id], language).format(params);

  <Cart
    getLocalization={(...args) => getLocalization(localization.en.cart, 'en', ...args)}
  />
```
Or you could use __getDefaultLocalization__ function from _cartLocalization_:
```javascript
  import React from 'react';
  import { Cart, cartLocalization } from 'react-shopping-cart';

  const { getDefaultLocalization } = cartLocalization;

  const localization = {
    GBP: '£',
    USD: '$',
  };

  <Cart
    getLocalization={getDefaultLocalization('cart', 'en', localization)}
  />
```
Example usage of __getLocalization__ function from _cartLocalization_:
```javascript
  import React from 'react';
  import { Cart, cartLocalization } from 'react-shopping-cart';

  const { getLocalization, defaultLocalization } = cartLocalization;

  const localization = {
    en: {
      cart : {
        GBP: '£',
      },
    },
  };

  const mergedEnCartLocalization = {
    ...localization.en.cart,
    ...defaultLocalization.en.cart,
  };

  <Cart
    getLocalization={(...args) => getLocalization(mergedEnCartLocalization, 'en', ...args)}
  />
```
For built-in getLocalization function you may write your translation for default statements as a string or object in format { component : Function | string, text : string, props? : object }. Because all components are pure, in order to relocalize your components, you should pass new getLocalization function, not old with changed scope.

__Localization__ default ids and params bindings:
- __cart:__
  - _no params_
    - shoppingCartTitle

  - _{
      quantity,
      price,
      total,
      currency,
      name,
      localizedName,
      localizedCurrency,
    }_
    - productName
    - quantityLabel
    - priceLabel
    - priceValue
    - totalLabel
    - totalValue
    - remove
    - ___your currency___
    - ___your product's name___

  - _{name, value, localizedName, localizedValue,}_
    - productPropertyLabel
    - productPropertyValue
    - ___your product's property name___
    - ___your product's property value (if string of course)___

- __checkoutButton__
  - _{currency, total, localizedCurrency,}_
    - checkoutTotal
    - ___your currency___

- __product__
  - _{
      name,
      quantity,
      price,
      currency,
      localizedName,
      localizedCurrency,
    }_
    - price
    - quantityLabel
    - propertyLabel
    - addToCart
    - ___your product's name___
    - ___your product's currency___
  - _{
      name,
      currency,
      localizedName,
      localizedCurrency,
    }_
    - ___your product's name___
    - ___your product's property name___
    - _{(optional) cost}_
      - ___your product's property value (if string of course)___

<!-- Generated by documentation.js. Update this documentation by updating the source code. -->

### Table of Contents

-   [Cart][1]
    -   [Props][2]
-   [CartProduct][3]
-   [ProductPropertyLabel][4]
-   [CheckoutButton][5]
    -   [Props][6]
-   [Product][7]
    -   [Props][8]
-   [ProductPropertiesOptions][9]
-   [ScrollPosition][10]
-   [ScrollFunction][11]
-   [ProductPropertyInput][12]
-   [OptionIndex][13]
-   [OptionObject][14]
-   [PropertyOption][15]
-   [PropertyOptions][16]
-   [OnChange][17]
-   [helpers][18]
    -   [configure][19]
    -   [isNaturalNumber][20]
    -   [parseInteger][21]
    -   [getAbsoluteOffsetTop][22]
    -   [DefaultLinkComponent][23]
    -   [fixInputValueStartingWithZero][24]
    -   [scrollFunction][25]
-   [ReactStatelessComponent][26]
-   [ProductPropertyOption][27]
-   [ProductProperties][28]
-   [Prices][29]
-   [ProductData][30]
-   [Products][31]
-   [GenerateProductKey][32]
-   [AddProduct][33]
-   [UpdateProduct][34]
-   [RemoveProduct][35]
-   [GetLocalization][36]
-   [CartAddAction][37]
-   [CartUpdateAction][38]
-   [CartRemoveAction][39]
-   [CartEmptyAction][40]
-   [CartSetCurrencyAction][41]
-   [CartAction][42]
-   [LocalizationPattern][43]
-   [Localization][44]
-   [MultiLocalization][45]
-   [CartState][46]
-   [DefaultLinkComponentProps][47]
-   [Link$Component][48]

## Cart

**Extends React.PureComponent**

Component which represents shopping cart.

**Meta**

-   **author**: Oleg Nosov &lt;olegnosov1@gmail.com>
-   **license**: MIT

### Props

Type: [Object][49]

**Properties**

-   `products` **[Products][50]** Products map. Required.
-   `currency` **[string][51]** Current currency. Required.
-   `isCartEmpty` **[boolean][52]** Display cart or not. Required.
-   `onUpdateProduct` **[UpdateProduct][53]** Function which will be called when product should be updated.
    First arg is product's key in products map, second - updated product. Required.
-   `onRemoveProduct` **[RemoveProduct][54]** Function to call when product should be removed from cart.
    One argument - product's key. Required.
-   `getLocalization` **[GetLocalization][55]** Required.
-   `hideHeader` **[boolean][52]?** Hide cart's header. Default is false.
-   `checkoutButton` **ReactElement?** Button to display in the bottom of cart. Default is null.
-   `iconTrashClassName` **[string][51]?** ClassName for trash icon on remove button.
    Default is 'fa fa-trash mx-1'.
-   `altProductImageSrc` **[string][51]?** Alt image src for products. Default is ''.
-   `cartCSSTransition` **[Object][49]?** Cart's config for react-transition-group/CSSTransition.
    Look at src/components/Cart/Cart.js for details.
-   `cartItemCSSTransition` **[Object][49]?** Cart item's config for react-transition-group/CSSTransition.
    Look at src/components/Cart/Cart.js for details.
-   `linkComponent` **[Link$Component][56]?** React Component, will receive prop `to="%your product's page%"`.
    I'd recommend you to take a look at react-router's Link.

## CartProduct

**Extends React.PureComponent**

React component to display product in cart.

**Meta**

-   **author**: Oleg Nosov &lt;olegnosov1@gmail.com>
-   **license**: MIT

## ProductPropertyLabel

**Extends React.PureComponent**

React component to display product's property value in cart.

**Meta**

-   **author**: Oleg Nosov &lt;olegnosov1@gmail.com>
-   **license**: MIT

## CheckoutButton

**Extends React.PureComponent**

Checkout button with grand total.

**Meta**

-   **author**: Oleg Nosov &lt;olegnosov1@gmail.com>
-   **license**: MIT

### Props

Type: [Object][49]

**Properties**

-   `grandTotal` **[number][57]** Required.
-   `currency` **[string][51]** Current currency. Required.
-   `hidden` **[boolean][52]** Show or hide button. Required.
-   `checkoutURL` **[string][51]** Link to checkout page. Required.
-   `getLocalization` **[GetLocalization][55]** Required.
-   `iconCheckoutClassName` **[string][51]?** ClassName for cart icon on checkout button. Default is 'fa fa-shopping-cart mx-1'.
-   `buttonCSSTransition` **[Object][49]?** Transition's config for react-transition-group/CSSTransition.
-   `linkComponent` **[Link$Component][56]?** React Component, will receive prop `to="%your product's page%"`.
    I'd recommend you to take a look at react-router's Link.

## Product

**Extends React.PureComponent**

React component - Product form with price.

**Meta**

-   **author**: Oleg Nosov &lt;olegnosov1@gmail.com>
-   **license**: MIT

### Props

Type: [Object][49]

**Properties**

-   `id` **[string][51]** Product's id. Required.
-   `name` **[string][51]** Name to display pattern. Required.
-   `path` **[string][51]** Path to product. Required.
-   `prices` **[Prices][58]** {currency: value}. Required
-   `imageSrc` **[string][51]** Path to main image. Required.
-   `currency` **[string][51]** Current price currency. Required.
-   `onAddProduct` **[AddProduct][59]** Function to call when user wants to add product in his cart. Required.
-   `generateProductKey` **[GenerateProductKey][60]** Required.
-   `getLocalization` **[GetLocalization][55]** Required.
-   `properties` **[ProductPropertiesOptions][61]?** Custom product properties. Each property option list consists of number,
    string or shape({ additionalCost(optional), onSelect(optional), value(required)})
-   `propertiesToShowInCart` **[Array][62]&lt;[string][51]>?** Array of propery names to display in cart.
-   `scrollAnimationConfig` **[Object][49]?** Config for animateScroll (from react-scroll) scrollTo function.
-   `scrollPosition` **[ScrollPosition][63]?** Position to scroll after product add. May be number or function returning number.
-   `scrollFunction` **[ScrollFunction][64]?** Function which will be called when product has been added.
-   `iconAddProductClassName` **[string][51]?** ClassName for cart icon on add to button. Default is 'fa fa-cart-plus mx-1'.
-   `checkoutButton` **ReactElement?** 
-   `descriptionNode` **ReactNode?** Node to display before price element.
-   `afterPriceNode` **ReactNode?** Node to display after price element.

## ProductPropertiesOptions

Type: [Object][49]&lt;[string][51], [PropertyOptions][65]>

## ScrollPosition

Type: ([number][57] | function (currentTarget: [Element][66]): [number][57])

## ScrollFunction

Type: function (currentTarget: EventTarget, scrollPosition: ([number][57] | function (currentTarget: [Element][66]): [number][57]), scrollAnimationConfig: [Object][49]): void

## ProductPropertyInput

**Extends React.PureComponent**

React form for product property(options select only).

**Meta**

-   **author**: Oleg Nosov &lt;olegnosov1@gmail.com>
-   **license**: MIT

## OptionIndex

Type: [Object][49]&lt;[string][51], [number][57]>

## OptionObject

Type: [Object][49]

## PropertyOption

Type: ([ProductPropertyOption][67] \| [OptionObject][68])

## PropertyOptions

Type: [Array][62]&lt;[PropertyOption][69]>

## OnChange

Type: function (obj: {value: [OptionIndex][70]}): void

## helpers

**Meta**

-   **author**: Oleg Nosov &lt;olegnosov1@gmail.com>
-   **license**: MIT

### configure

**Parameters**

-   `Component` **[Function][71]** 
-   `configuration` **[Object][49]** 

Returns **[ReactStatelessComponent][72]** 

### isNaturalNumber

**Parameters**

-   `num` **[number][57]** 

Returns **[boolean][52]** 

### parseInteger

**Parameters**

-   `num` **[string][51]** 

Returns **[number][57]** 

### 

### getAbsoluteOffsetTop

**Parameters**

-   `$0` **any**  (optional, default `{}`)
    -   `$0.offsetTop`  
    -   `$0.offsetParent`  

Returns **[number][57]** 

### DefaultLinkComponent

**Parameters**

-   `$0` **any** 
    -   `$0.to`  
    -   `$0.otherProps` **...any** 

Returns **React$Element&lt;any>** 

### fixInputValueStartingWithZero

**Parameters**

-   `target` **[HTMLInputElement][73]** 
-   `quantity` **[number][57]** 

### scrollFunction

**Parameters**

-   `target` **EventTarget** 
-   `scrollPosition` **([number][57] | function (currentTarget: [Element][66]): [number][57])** 
-   `scrollAnimationConfig` **[Object][49]** 

## ReactStatelessComponent

Type: function (props: [Object][49]): React$Element&lt;any>

## 

Shopping cart's data types

**Meta**

-   **author**: Oleg Nosov &lt;olegnosov1@gmail.com>
-   **license**: MIT

## ProductPropertyOption

Type: ([string][51] \| [number][57])

## ProductProperties

Type: [Object][49]&lt;[string][51], ([string][51] \| [number][57])>

## Prices

Type: [Object][49]&lt;[string][51], [number][57]>

## ProductData

Type: {id: [string][51], quantity: [number][57], properties: [ProductProperties][74], name: [string][51], prices: [Prices][58], imageSrc: [string][51], path: [string][51], propertiesToShowInCart: [Array][62]&lt;[string][51]>}

**Properties**

-   `id` **[string][51]** 
-   `quantity` **[number][57]** 
-   `properties` **[ProductProperties][74]** 
-   `name` **[string][51]** 
-   `prices` **[Prices][58]** 
-   `imageSrc` **[string][51]** 
-   `path` **[string][51]** 
-   `propertiesToShowInCart` **[Array][62]&lt;[string][51]>** 

**Examples**

```javascript
{
   id: 'macbook-case',
   quantity: 3,
   properties: {
     color: 'red'
   },
   name: 'macbookCase',
   prices: {
    GBP: 50
   },
   path: '/shop/macbook-case/',
   imageSrc: '/shop/macbook-case/1-483x321.jpeg',
   propertiesToShowInCart: ['color']
 }
```

## Products

Type: [Object][49]&lt;[string][51], [ProductData][75]>

## GenerateProductKey

Type: function (id: [string][51], properties: [ProductProperties][74]): [string][51]

## AddProduct

Type: function (key: [string][51], product: [ProductData][75], currency: [string][51]): void

## UpdateProduct

Type: function (key: [string][51], updatedProduct: [ProductData][75]): void

## RemoveProduct

Type: function (key: [string][51]): void

## GetLocalization

Type: function (id: [string][51], params: [Object][49]): ([string][51] | React$Element&lt;any>)

## CartAddAction

Type: {type: `"cart/ADD"`, key: [string][51], product: [ProductData][75], productCurrency: [string][51]}

**Properties**

-   `type` **`"cart/ADD"`** 
-   `key` **[string][51]** 
-   `product` **[ProductData][75]** 
-   `productCurrency` **[string][51]** 

## CartUpdateAction

Type: {type: `"cart/UPDATE"`, key: [string][51], updatedProduct: [ProductData][75]}

**Properties**

-   `type` **`"cart/UPDATE"`** 
-   `key` **[string][51]** 
-   `updatedProduct` **[ProductData][75]** 

## CartRemoveAction

Type: {type: `"cart/REMOVE"`, key: [string][51]}

**Properties**

-   `type` **`"cart/REMOVE"`** 
-   `key` **[string][51]** 

## CartEmptyAction

Type: {type: `"cart/EMPTY"`}

**Properties**

-   `type` **`"cart/EMPTY"`** 

## CartSetCurrencyAction

Type: {type: `"cart/SET_CURRENCY"`, currency: [string][51]}

**Properties**

-   `type` **`"cart/SET_CURRENCY"`** 
-   `currency` **[string][51]** 

## CartAction

Type: ([CartAddAction][76] \| [CartUpdateAction][77] \| [CartRemoveAction][78] \| [CartEmptyAction][79] \| [CartSetCurrencyAction][80])

## LocalizationPattern

Type: ([string][51] | {component: ([string][51] | function (): React$Element&lt;any>), props: [Object][49]?, text: [string][51]})

## Localization

Type: [Object][49]&lt;[string][51], [LocalizationPattern][81]>

## MultiLocalization

Type: [Object][49]&lt;[string][51], [Object][49]&lt;[string][51], [Localization][82]>>

## CartState

Type: {cart: {currency: [string][51], products: [Products][50]}}

**Properties**

-   `cart` **{currency: [string][51], products: [Products][50]}** 
-   `cart.currency` **[string][51]** 
-   `cart.products` **[Products][50]** 

## DefaultLinkComponentProps

Type: {to: [string][51]}

**Properties**

-   `to` **[string][51]** 

## Link$Component

Type: function ([DefaultLinkComponentProps][83]): React$Element&lt;any>

[1]: #cart

[2]: #props

[3]: #cartproduct

[4]: #productpropertylabel

[5]: #checkoutbutton

[6]: #props-1

[7]: #product

[8]: #props-2

[9]: #productpropertiesoptions

[10]: #scrollposition

[11]: #scrollfunction

[12]: #productpropertyinput

[13]: #optionindex

[14]: #optionobject

[15]: #propertyoption

[16]: #propertyoptions

[17]: #onchange

[18]: #helpers

[19]: #configure

[20]: #isnaturalnumber

[21]: #parseinteger

[22]: #getabsoluteoffsettop

[23]: #defaultlinkcomponent

[24]: #fixinputvaluestartingwithzero

[25]: #scrollfunction-1

[26]: #reactstatelesscomponent

[27]: #productpropertyoption

[28]: #productproperties

[29]: #prices

[30]: #productdata

[31]: #products

[32]: #generateproductkey

[33]: #addproduct

[34]: #updateproduct

[35]: #removeproduct

[36]: #getlocalization

[37]: #cartaddaction

[38]: #cartupdateaction

[39]: #cartremoveaction

[40]: #cartemptyaction

[41]: #cartsetcurrencyaction

[42]: #cartaction

[43]: #localizationpattern

[44]: #localization

[45]: #multilocalization

[46]: #cartstate

[47]: #defaultlinkcomponentprops

[48]: #linkcomponent

[49]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Object

[50]: #products

[51]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String

[52]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Boolean

[53]: #updateproduct

[54]: #removeproduct

[55]: #getlocalization

[56]: #linkcomponent

[57]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Number

[58]: #prices

[59]: #addproduct

[60]: #generateproductkey

[61]: #productpropertiesoptions

[62]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Array

[63]: #scrollposition

[64]: #scrollfunction

[65]: #propertyoptions

[66]: https://developer.mozilla.org/docs/Web/API/Element

[67]: #productpropertyoption

[68]: #optionobject

[69]: #propertyoption

[70]: #optionindex

[71]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Statements/function

[72]: #reactstatelesscomponent

[73]: https://developer.mozilla.org/docs/Web/API/HTMLInputElement

[74]: #productproperties

[75]: #productdata

[76]: #cartaddaction

[77]: #cartupdateaction

[78]: #cartremoveaction

[79]: #cartemptyaction

[80]: #cartsetcurrencyaction

[81]: #localizationpattern

[82]: #localization

[83]: #defaultlinkcomponentprops


## Development

**Developer mode**

Run [webpack-dev-server](https://github.com/webpack/webpack-dev-server) for example1
```shell
yarn start
```
```shell
npm run start
```

**Build**

```shell
yarn build
```
```shell
npm run build
```
And then check dist folder

**Build Example**

```shell
yarn build_example
```
```shell
npm run build_example
```
And then check examples folder


**Testing**

[Jest](https://github.com/facebook/jest) is used for tests
```shell
yarn test
```
```shell
npm run test
```

**Linter**

[ESLint](https://github.com/eslint/eslint) is used as linter
```shell
yarn lint
```
```shell
npm run lint
```

**Flow Type**

Check types in project using [Flow](https://github.com/facebook/flow)
```shell
yarn flow
```
```shell
npm run flow
```

**Autodoc**

Generate doc using [documentation js](https://github.com/documentationjs/documentation)
```shell
yarn doc
```
```shell
npm run doc
```
And then look at README.md
